@@ -1,21 +1,42 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-""" Encapsulates report generation functions """
-
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
+"""Encapsulates report generation functions."""
+from builtins import object  # pylint: disable=W0622
+from io import open
 from sys import version_info
+
 import pandas as pd
 
 from .. import config
 from ..utils.misc import BIDS_COMP
 
-from builtins import object  # pylint: disable=W0622
-from io import open
-
 
 def gen_html(csv_file, mod, csv_failed=None, out_file=None):
-    import os.path as op
     import datetime
+    import os.path as op
+
     from pkg_resources import resource_filename as pkgrf
+
     from .. import __version__ as ver
     from ..data import GroupTemplate
 
